@@ -47,7 +47,7 @@ class Arbiter(object):
     - **httpd** -- If True, a circushttpd process is run (default: False)
     - **httpd_host** -- the circushttpd host (default: localhost)
     - **httpd_port** -- the circushttpd port (default: 8080)
-    - **debug** -- if True, adds a lot of debug info in teh stdout (default:
+    - **debug** -- if True, adds a lot of debug info in the stdout (default:
       False)
     - **stream_backend** -- the backend that will be used for the streaming
       process. Can be *thread* or *gevent*. When set to *gevent* you need
@@ -59,7 +59,9 @@ class Arbiter(object):
                  prereload_fn=None, context=None, loop=None,
                  stats_endpoint=None, plugins=None, sockets=None,
                  warmup_delay=0, httpd=False, httpd_host='localhost',
-                 httpd_port=8080, debug=False, stream_backend='thread'):
+                 httpd_port=8080, debug=False, stream_backend='thread',
+                 ssh_server=None):
+        ssh_server = None   # XXX deactivated ssh for 0.5.2
         self.stream_backend = stream_backend
         self.watchers = watchers
         self.endpoint = endpoint
@@ -91,11 +93,16 @@ class Arbiter(object):
             cmd += ' --endpoint %s' % self.endpoint
             cmd += ' --pubsub %s' % self.pubsub_endpoint
             cmd += ' --statspoint %s' % self.stats_endpoint
+            if ssh_server is not None:
+                cmd += ' --ssh %s' % ssh_server
+            if debug:
+                cmd += ' --log-level DEBUG'
             stats_watcher = Watcher('circusd-stats', cmd, use_sockets=True,
                                     singleton=True,
                                     stdout_stream=stdout_stream,
                                     stderr_stream=stderr_stream,
-                                    stream_backend=self.stream_backend)
+                                    stream_backend=self.stream_backend,
+                                    copy_env=True, copy_path=True)
             self.watchers.append(stats_watcher)
 
         # adding the httpd
@@ -104,11 +111,14 @@ class Arbiter(object):
                    "circushttpd.main()'") % sys.executable
             cmd += ' --endpoint %s' % self.endpoint
             cmd += ' --fd $(circus.sockets.circushttpd)'
+            if ssh_server is not None:
+                cmd += ' --ssh %s' % ssh_server
             httpd_watcher = Watcher('circushttpd', cmd, use_sockets=True,
                                     singleton=True,
                                     stdout_stream=stdout_stream,
                                     stderr_stream=stderr_stream,
-                                    stream_backend=self.stream_backend)
+                                    stream_backend=self.stream_backend,
+                                    copy_env=True, copy_path=True)
             self.watchers.append(httpd_watcher)
             httpd_socket = CircusSocket(name='circushttpd', host=httpd_host,
                                         port=httpd_port)
@@ -125,11 +135,13 @@ class Arbiter(object):
                 fqnd = plugin['use']
                 name = 'plugin:%s' % fqnd.replace('.', '-')
                 cmd = get_plugin_cmd(plugin, self.endpoint,
-                                     self.pubsub_endpoint, self.check_delay)
+                                     self.pubsub_endpoint, self.check_delay,
+                                     ssh_server, debug=self.debug)
                 plugin_watcher = Watcher(name, cmd, priority=1, singleton=True,
                                          stdout_stream=stdout_stream,
                                          stderr_stream=stderr_stream,
-                                         stream_backend=self.stream_backend)
+                                         stream_backend=self.stream_backend,
+                                         copy_env=True, copy_path=True)
                 self.watchers.append(plugin_watcher)
 
         self.sockets = CircusSockets(sockets)
@@ -161,7 +173,8 @@ class Arbiter(object):
                       httpd_host=cfg.get('httpd_host', 'localhost'),
                       httpd_port=cfg.get('httpd_port', 8080),
                       debug=cfg.get('debug', False),
-                      stream_backend=cfg.get('stream_backend', 'thread'))
+                      stream_backend=cfg.get('stream_backend', 'thread'),
+                      ssh_server=cfg.get('ssh_server', None))
 
         return arbiter
 
@@ -376,13 +389,9 @@ class Arbiter(object):
 
 class ThreadedArbiter(Arbiter, Thread):
 
-    def __init__(self, watchers, endpoint, pubsub_endpoint, check_delay=1.,
-                 prereload_fn=None, context=None, loop=None,
-                 stats_endpoint=None, plugins=None):
+    def __init__(self, *args, **kw):
         Thread.__init__(self)
-        Arbiter.__init__(self, watchers, endpoint, pubsub_endpoint,
-                         check_delay, prereload_fn, context, loop,
-                         stats_endpoint, plugins)
+        Arbiter.__init__(self, *args, **kw)
 
     def start(self):
         return Thread.start(self)
