@@ -1,6 +1,6 @@
 from circus.commands.base import Command
-from circus.commands.start import Start
-from circus.exc import ArgumentError
+from circus.commands.util import validate_option
+from circus.exc import ArgumentError, MessageError
 
 
 class AddWatcher(Command):
@@ -20,13 +20,19 @@ class AddWatcher(Command):
                 "properties": {
                     "cmd": "/path/to/commandline --option"
                     "name": "nameofwatcher"
+                    "args": [],
+                    "options": {},
+                    "start": false
                 }
             }
 
         A message contains 2 properties:
 
         - cmd: Full command line to execute in a process
+        - args: array, arguments passed to the command (optional)
         - name: name of watcher
+        - options: options of a watcher
+        - start: start the watcher after the creation
 
         The response return a status "ok".
 
@@ -41,7 +47,7 @@ class AddWatcher(Command):
         +++++++
 
         - <name>: name of the watcher to create
-        - <cmd>: ull command line to execute in a process
+        - <cmd>: full command line to execute in a process
         - --start: start the watcher immediately
 
     """
@@ -54,13 +60,22 @@ class AddWatcher(Command):
         if len(args) < 2:
             raise ArgumentError("number of arguments invalid")
 
-        msg = self.make_message(name=args[0], cmd=" ".join(args[1:]))
-        if opts.get("start", False):
-            return [{'cmd': self,
-                     'msg': msg},
-                    {'cmd': Start(),
-                     'msg': self.make_message(command="start", name=args[0])}]
-        return msg
+        return self.make_message(name=args[0], cmd=" ".join(args[1:]),
+                start=opts.get('start', False))
 
     def execute(self, arbiter, props):
-        arbiter.add_watcher(props['name'], props['cmd'])
+        options = props.get('options', {})
+        watcher = arbiter.add_watcher(props['name'], props['cmd'],
+                                      args=props.get('args'), **options)
+        if props.get('start', False):
+            watcher.start()
+
+    def validate(self, props):
+        super(AddWatcher, self).validate(props)
+        if 'options' in props:
+            options = props.get('options')
+            if not isinstance(options, dict):
+                raise MessageError("'options' property should be an object")
+
+            for key, val in props['options'].items():
+                validate_option(key, val)
