@@ -11,10 +11,10 @@ class StatsdEmitter(CircusPlugin):
     """
     name = 'statsd'
 
-    def __init__(self, endpoint, pubsub_endpoint, check_delay,
+    def __init__(self, endpoint, pubsub_endpoint, check_delay, ssh_server,
                  **config):
         super(StatsdEmitter, self).__init__(endpoint, pubsub_endpoint,
-                                            check_delay)
+                                            check_delay, ssh_server=ssh_server)
         self.app = config.get('application_name', 'app')
         self.prefix = 'circus.%s.watcher' % self.app
 
