@@ -11,11 +11,13 @@ import zmq
 
 from circus.consumer import CircusConsumer
 from circus import __version__
+from circus.util import DEFAULT_ENDPOINT_STATS
 
 
 class StatsClient(CircusConsumer):
-    def __init__(self, endpoint='tcp://127.0.0.1:5557', context=None):
-        CircusConsumer.__init__(self, ['stat.'], context, endpoint)
+    def __init__(self, endpoint=DEFAULT_ENDPOINT_STATS, ssh_server=None,
+                 context=None):
+        CircusConsumer.__init__(self, ['stat.'], context, endpoint, ssh_server)
 
     def iter_messages(self):
         """ Yields tuples of (watcher, subtopic, stat)"""
@@ -23,6 +25,16 @@ class StatsClient(CircusConsumer):
 
         with self:
             while True:
+                try:
+                    events = dict(self.poller.poll(self.timeout * 1000))
+                except zmq.ZMQError as e:
+                    if e.errno == errno.EINTR:
+                        continue
+
+                if len(events) == 0:
+                    print 'nothing'
+                    continue
+
                 try:
                     topic, stat = recv()
                 except zmq.core.error.ZMQError, e:
@@ -181,11 +193,13 @@ def main():
 
     parser.add_argument('--endpoint',
             help='The circusd-stats ZeroMQ socket to connect to',
-            default='tcp://127.0.0.1:5557')
+            default=DEFAULT_ENDPOINT_STATS)
 
     parser.add_argument('--version', action='store_true',
                      default=False, help='Displays Circus version and exits.')
 
+    parser.add_argument('--ssh', default=None, help='SSH Server')
+
     args = parser.parse_args()
 
     if args.version:
@@ -201,7 +215,7 @@ def main():
     painter.start()
 
     try:
-        client = StatsClient(args.endpoint)
+        client = StatsClient(args.endpoint, args.ssh)
         try:
             for watcher, subtopic, stat in client:
                 # building the line
