@@ -12,11 +12,11 @@ def run_process(*args, **kw):
     try:
         i = 0
         while True:
-            sys.stdout.write('%d-stdout-%d-%s\n' % (time.time(),
-                                                     os.getpid(), i))
+            sys.stdout.write('%.2f-stdout-%d-%s\n' % (time.time(),
+                                                      os.getpid(), i))
             sys.stdout.flush()
-            sys.stderr.write('%d-stderr-%d-%s\n' % (time.time(),
-                                                     os.getpid(), i))
+            sys.stderr.write('%.2f-stderr-%d-%s\n' % (time.time(),
+                                                      os.getpid(), i))
             sys.stderr.flush()
             time.sleep(.25)
     except:
@@ -59,12 +59,11 @@ class TestWatcher(TestCircus):
         self.call('restart')
         time.sleep(1.)
 
-        current = time.time()
         # should be running
         with open(self.log) as f:
             data = f.readlines()
 
         # last log should be less than one second old
         last = data[-1]
-        delta = abs(current - int(last.split('-')[0]))
-        self.assertTrue(delta < 1, delta)
+        delta = abs(time.time() - float(last.split('-')[0]))
+        self.assertTrue(delta < 1., delta)
