@@ -46,13 +46,13 @@ class TestWatcher(TestCircus):
         resp = self.call(cmd, **props)
         return resp.get('numprocesses')
 
+    def pids(self):
+        return self.call('list', name='test').get('pids')
+
     def test_signal(self):
         self.assertEquals(self.numprocesses('incr', name='test'), 2)
 
-        def get_pids():
-            return self.call('list', name='test').get('pids')
-
-        pids = get_pids()
+        pids = self.pids()
         self.assertEquals(len(pids), 2)
         to_kill = pids[0]
         self.assertEquals(self.status('signal', name='test', pid=to_kill,
@@ -61,7 +61,7 @@ class TestWatcher(TestCircus):
         time.sleep(1)  # wait for the process to die
 
         # we still should have two processes, but not the same pids for them
-        pids = get_pids()
+        pids = self.pids()
         self.assertEquals(len(pids), 2)
         self.assertTrue(to_kill not in pids)
 
@@ -78,6 +78,16 @@ class TestWatcher(TestCircus):
         # let's see what we got
         self.assertTrue(self.stream.qsize() > 1)
 
+    def test_max_age(self):
+        result = self.call('set', name='test',
+                           options={'max_age': 1, 'max_age_variance': 0})
+        self.assertEquals(result.get('status'), 'ok')
+        initial_pids = self.pids()
+        time.sleep(3.0)  # allow process to reach max_age and restart
+        current_pids = self.pids()
+        self.assertEqual(len(current_pids), 1)
+        self.assertNotEqual(initial_pids, current_pids)
+
 
 class TestWatcherFromConfiguration(TestCircus):
 
@@ -104,3 +114,26 @@ class TestWatcherInitialization(TestCircus):
                               {'COCONUTS': 'MIGRATE', 'AWESOMENESS': 'YES'})
         finally:
             os.environ = old_environ
+
+    def test_copy_path(self):
+        stream = QueueStream()
+        qstream = {'stream': stream}
+        old_environ = os.environ
+        old_paths = sys.path[:]
+        try:
+            sys.path = ['KEUKEUNEUT']
+            os.environ = {'COCONUTS': 'MIGRATE'}
+            cmd = ('%s -c "import sys; '
+                   'sys.stdout.write(\':\'.join(sys.path)); '
+                   ' sys.stdout.flush()"') % sys.executable
+            watcher = Watcher('xx', cmd, copy_env=True, copy_path=True,
+                              stdout_stream=qstream)
+            watcher.start()
+            time.sleep(2.)
+            watcher.stop()
+            data = [v for k, v in stream.get().items()][1]
+            data = ''.join(data)
+            self.assertTrue('KEUKEUNEUT' in data, data)
+        finally:
+            os.environ = old_environ
+            sys.path[:] = old_paths
